===============================
kibitzr
===============================

.. image:: https://badges.gitter.im/kibitzr/Lobby.svg
   :alt: Join the chat at https://gitter.im/kibitzr/Lobby
   :target: https://gitter.im/kibitzr/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge


.. image:: https://img.shields.io/pypi/v/kibitzr.svg
        :target: https://pypi.python.org/pypi/kibitzr

.. image:: https://img.shields.io/travis/kibitzr/kibitzr.svg
        :target: https://travis-ci.org/kibitzr/kibitzr

.. image:: https://readthedocs.org/projects/kibitzr/badge/?version=latest
        :target: https://kibitzr.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Self hosted web page changes monitoring


* Free software: MIT license
* Documentation: https://kibitzr.readthedocs.io.


Features
--------

* Easy to install and run
* Whole configuration in one YAML file
* Python requests for simple HTTP queries (with optional JSON formatting)
* Firefox for complex interactions with scenarios and HTML parsing
* BeautifulSoup for formatting HTML contents
* E-mail notifications through MailGun 
* Extensible with bash and python scripts
* Vibrant friendly community (on gitter)
* Python 2 and 3 compatible


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

